# valladopy

`valladopy` is a Python library offering validated astrodynamics routines from the well-known textbook "Fundaments of Astrodynamics and Applications" by David Vallado.

---

## Installation

Install the package via pip:
```bash
pip install valladopy
```

---

## Contributing

We appreciate interest in contributing to this project! However, as we are still figuring this process out, we ask contributors to first [submit an issue in GitHub](https://github.com/CelesTrak/fundamentals-of-astrodynamics/issues).

---

## License

`valladopy` is licensed under the GNU Affero General Public License v3.0 (AGPLv3). See the [LICENSE](https://github.com/CelesTrak/fundamentals-of-astrodynamics/blob/main/LICENSE) file for details.